@@ -136,7 +136,7 @@ ImageDialog::ImageDialog(TQWidget* parent, KIPI::Interface* interface,
     TQPushButton *helpButton = actionButton( Help );
     KHelpMenu* helpMenu = new KHelpMenu(this, about, false);
     helpMenu->menu()->removeItemAt(0);
-    helpMenu->menu()->insertItem(i18n("Kipi Plugins Handbooks"), this, TQT_SLOT(slotHelp()), 0, -1, 0);
+    helpMenu->menu()->insertItem(i18n("Kipi Plugins Handbooks"), this, TQ_SLOT(slotHelp()), 0, -1, 0);
     helpButton->setPopup( helpMenu->menu() );
 
     //---------------------------------------------
@@ -168,17 +168,17 @@ ImageDialog::ImageDialog(TQWidget* parent, KIPI::Interface* interface,
     for(; it!=d->_albums.end(); ++it) {
         new AlbumLVI(d->_albumList, *it);
     }
-    TQTimer::singleShot(0, this, TQT_SLOT(slotInitialShow()));
+    TQTimer::singleShot(0, this, TQ_SLOT(slotInitialShow()));
 
-    connect(d->_albumList, TQT_SIGNAL(selectionChanged(TQListViewItem*)),
-            this, TQT_SLOT(fillImageList(TQListViewItem*)) );
+    connect(d->_albumList, TQ_SIGNAL(selectionChanged(TQListViewItem*)),
+            this, TQ_SLOT(fillImageList(TQListViewItem*)) );
 
     if (singleSelection)
-        connect(d->_imageList, TQT_SIGNAL(selectionChanged(TQListViewItem*)),
-                this, TQT_SLOT(slotImageSelected(TQListViewItem*)) );
+        connect(d->_imageList, TQ_SIGNAL(selectionChanged(TQListViewItem*)),
+                this, TQ_SLOT(slotImageSelected(TQListViewItem*)) );
     else
-        connect(d->_imageList, TQT_SIGNAL(selectionChanged()),
-                this, TQT_SLOT(slotImagesSelected()));
+        connect(d->_imageList, TQ_SIGNAL(selectionChanged()),
+                this, TQ_SLOT(slotImagesSelected()));
 
     enableButtonOK(false);
 }
@@ -246,8 +246,8 @@ void ImageDialog::slotImageSelected(TQListViewItem* item) {
     d->_preview->clear();
 
     TDEIO::PreviewJob* thumbJob = TDEIO::filePreview(d->_url, PREVIEW_SIZE);
-    connect( thumbJob, TQT_SIGNAL(gotPreview(const KFileItem*, const TQPixmap&)),
-             TQT_SLOT(slotGotPreview(const KFileItem* , const TQPixmap&)));
+    connect( thumbJob, TQ_SIGNAL(gotPreview(const KFileItem*, const TQPixmap&)),
+             TQ_SLOT(slotGotPreview(const KFileItem* , const TQPixmap&)));
 }
 
 void ImageDialog::slotImagesSelected()
@@ -284,8 +284,8 @@ void ImageDialog::slotImagesSelected()
         d->_url = d->_urls.first();
 
         TDEIO::PreviewJob* thumbJob = TDEIO::filePreview(d->_url, PREVIEW_SIZE);
-        connect( thumbJob, TQT_SIGNAL(gotPreview(const KFileItem*, const TQPixmap&)),
-                 TQT_SLOT(slotGotPreview(const KFileItem* , const TQPixmap&)));
+        connect( thumbJob, TQ_SIGNAL(gotPreview(const KFileItem*, const TQPixmap&)),
+                 TQ_SLOT(slotGotPreview(const KFileItem* , const TQPixmap&)));
     }
     else
     {
